@@ -5,6 +5,7 @@ from __future__ import annotations
 import os
 import shutil
 import subprocess
+import sys
 from pathlib import PurePosixPath
 
 import git
@@ -295,6 +296,14 @@ def sync(
             help="Enable verbose output.",
         ),
     ] = False,
+    force: Annotated[
+        bool,
+        typer.Option(
+            "--force",
+            "-f",
+            help="Force push to Overleaf even if there are conflicts.",
+        ),
+    ] = False,
 ):
     """Sync publications with Overleaf."""
     # TODO: We should probably ensure the pipeline isn't stale
@@ -372,25 +381,55 @@ def sync(
                 "Overleaf config"
             )
         elif last_sync_commit:
-            # Compute a diff in the Overleaf project between HEAD and the last
+            # Compute a patch in the Overleaf project between HEAD and the last
             # sync
-            diff = overleaf_repo.git.diff(
-                [last_sync_commit, "HEAD", "--"] + git_sync_paths
+            patch = overleaf_repo.git.format_patch(
+                [f"{last_sync_commit}..HEAD", "--stdout", "--"]
+                + git_sync_paths
             )
-            # Ensure the diff ends with a new line
-            if diff and not diff.endswith("\n"):
-                diff += "\n"
+            # Replace any Overleaf commit messages to make them more meaningful
+            patch = patch.replace(
+                "Update on Overleaf.", f"Update {wdir} on Overleaf"
+            )
+            # Ensure the patch ends with a new line
+            if patch and not patch.endswith("\n"):
+                patch += "\n"
             if verbose:
-                typer.echo(f"Git diff:\n{diff}")
-            if diff:
+                typer.echo(f"Git patch:\n{patch}")
+            if patch:
                 typer.echo("Applying to project repo")
                 process = subprocess.run(
-                    ["git", "apply", "--directory", wdir, "-"],
-                    input=diff,
+                    [
+                        "git",
+                        "am",
+                        "--3way",
+                        "--reject",
+                        "--directory",
+                        wdir,
+                        "-",
+                    ],
+                    input=patch,
                     text=True,
+                    encoding="utf-8",
                 )
                 if process.returncode != 0:
-                    raise_error("Failed to apply diff")
+                    if force:
+                        # Skip any patches we might be in the middle of
+                        try:
+                            repo.git.am("--skip")
+                        except Exception:
+                            pass
+                        typer.echo(
+                            "Failed to apply Overleaf patch to project repo. "
+                            "Proceeding to push project changes to Overleaf "
+                            "anyway."
+                        )
+                    else:
+                        raise_error(
+                            "Failed to apply Overleaf patch to project repo. "
+                            "Check the .rej files and manually apply changes, "
+                            "delete them, then rerun with --force."
+                        )
             else:
                 typer.echo("No changes to apply")
         else:
@@ -466,7 +505,7 @@ def sync(
             typer.echo(f"Adding DVC sync path {dvc_sync_path} to DVC")
             try:
                 subprocess.run(
-                    ["python", "-m", "dvc", "-q", "add", dvc_sync_path],
+                    [sys.executable, "-m", "dvc", "-q", "add", dvc_sync_path],
                     check=True,
                 )
             except subprocess.CalledProcessError as e:
@@ -492,5 +531,5 @@ def sync(
         typer.echo("Pushing changes to project Git remote")
         repo.git.push()
         if dvc_sync_paths:
-            subprocess.run(["python", "-m", "dvc", "push"])
+            subprocess.run([sys.executable, "-m", "dvc", "push"])
     # TODO: Add option to run the pipeline after?
